@@ -29,7 +29,7 @@ use Image::ExifTool::IPTC;
 use Image::ExifTool::Canon;
 use Image::ExifTool::Nikon;
 
-$VERSION = '1.72';
+$VERSION = '1.77';
 @ISA = qw(Exporter);
 
 sub NumbersFirst;
@@ -93,19 +93,21 @@ name may be followed by a number in square brackets to indicate the number
 of values written, or the number of characters in a fixed-length string
 (including a null terminator which is added if required).
 
-An asterisk (C<*>) after an entry in the B<Writable> column indicates a
-"protected" tag which is not writable directly, but is set via a Composite
-or Extra tag.  A tilde (C<~>) indicates a tag this is only writable when
-print conversion is disabled (by setting PrintConv to 0, or using the -n
-option). A slash (C</>) indicates an "avoided" tag that is not created
-unless the group is specified (due to name conflicts with other tags).  An
-exclamation point (C<!>) indicates a tag that is considered unsafe to write
-under normal circumstances.  These "unsafe" tags are not set when calling
+A plus sign (C<+>) after an entry in the B<Writable> column indicates a
+"list" tag which supports multiple values and allows individual values to be
+added and deleted.  A slash (C</>) indicates an "avoided" tag that is not
+created when writing if another same-named tag may be created instead.  To
+write these tags, the group should be specified.  A tilde (C<~>) indicates a
+tag this is writable only when the print conversion is disabled (by setting
+PrintConv to 0, or using the -n option).  An exclamation point (C<!>)
+indicates a tag that is considered unsafe to write under normal
+circumstances.  These "unsafe" tags are not set when calling
 SetNewValuesFromFile() or when using the exiftool -TagsFromFile option
 unless specified explicitly, and care should be taken when editing them
-manually since they may affect the way an image is rendered.  A plus sign
-(C<+>) indicates a "list" tag which supports multiple values and allows
-individual values to be added and deleted.
+manually since they may affect the way an image is rendered.  An asterisk
+(C<*>) indicates a "protected" tag which is not writable directly, but is
+written automatically by exiftool (often when a corresponding Composite or
+Extra tag is written).
 
 The HTML version of these tables also list possible B<Values> for
 discrete-valued tags, as well as B<Notes> for some tags.
@@ -153,8 +155,9 @@ API).
 XMP stands for "Extensible Metadata Platform", an XML/RDF-based metadata
 format which is being pushed by Adobe.  Information in this format can be
 embedded in many different image file types including JPG, JP2, TIFF, GIF,
-PS, PDF, PSD, DNG, PNG, SVG and MIFF, as well as audio file formats
-supporting ID3v2 information.
+EPS, PDF, PSD, DNG, PNG, DJVU, SVG and MIFF, as well as MOV, AVI, ASF, WMV,
+FLV, SWF and MP4 videos, and WMA and audio formats supporting ID3v2
+information.
 
 The XMP B<Tag ID>'s aren't listed because in most cases they are identical
 to the B<Tag Name>.
@@ -187,7 +190,7 @@ for the tag, ie) XMP-exif:Contrast or XMP-crs:Contrast.
 ExifTool will extract XMP information even if it is not listed in these
 tables.  For example, the C<pdfx> namespace doesn't have a predefined set of
 tag names because it is used to store application-defined PDF information,
-but this information is extracted by ExifTool anyway.
+but this information is extracted by ExifTool.
 },
     IPTC => q{
 IPTC stands for "International Press Telecommunications Council".  This is
@@ -291,10 +294,10 @@ and RPM).
 },
     Extra => q{
 The extra tags represent extra information extracted or generated by
-ExifTool that is not associated with another tag group.  The three writable
-"pseudo" tags (Filename, Directory and FileModifyDate) may be written
-without the need to rewrite the file since their values are not contained
-within the file data.
+ExifTool that is not directly associated with another tag group.  The three
+writable "pseudo" tags (Filename, Directory and FileModifyDate) may be
+written without the need to rewrite the file since their values are not
+contained within the file data.
 },
     Composite => q{
 The values of the composite tags are B<Derived From> the values of other
@@ -528,6 +531,7 @@ TagID:  foreach $tagID (@keys) {
                             $sepTable{$s} = $printConv;
                             # add PrintHex flag to PrintConv so we can check it later
                             $$printConv{PrintHex} = 1 if $$tagInfo{PrintHex};
+                            $$printConv{PrintString} = 1 if $$tagInfo{PrintString};
                         } else {
                             $caseInsensitive = 0;
                             my @pk = sort NumbersFirst keys %$printConv;
@@ -539,7 +543,7 @@ TagID:  foreach $tagID (@keys) {
                                 my $index;
                                 if ($$tagInfo{PrintHex} or $$printConv{BITMASK}) {
                                     $index = sprintf('0x%x',$_);
-                                } elsif (/^[+-]?(?=\d|\.\d)\d*(\.\d*)?$/) {
+                                } elsif (/^[+-]?(?=\d|\.\d)\d*(\.\d*)?$/ and not $$tagInfo{PrintString}) {
                                     $index = $_;
                                 } else {
                                     $index = $_;
@@ -737,8 +741,8 @@ sub WriteTagLookup($$)
 # open/create necessary files and transfer file headers
 #
     my $tmpFile = "${file}_tmp";
-    open(INFILE,$file) or warn("Can't open $file\n"), return 0;
-    unless (open(OUTFILE,">$tmpFile")) {
+    open(INFILE, $file) or warn("Can't open $file\n"), return 0;
+    unless (open(OUTFILE, ">$tmpFile")) {
         warn "Can't create temporary file $tmpFile\n";
         close(INFILE);
         return 0;
@@ -1038,9 +1042,9 @@ sub OpenHtmlFile($;$$)
         $head = $title = 'ExifTool Tag Names';
     }
     if ($createdFiles{$htmlFile}) {
-        open(HTMLFILE,">>${htmlFile}_tmp") or return 0;
+        open(HTMLFILE, ">>${htmlFile}_tmp") or return 0;
     } else {
-        open(HTMLFILE,">${htmlFile}_tmp") or return 0;
+        open(HTMLFILE, ">${htmlFile}_tmp") or return 0;
         print HTMLFILE "$docType<html>\n<head>\n<title>$title</title>\n";
         print HTMLFILE "<link rel=stylesheet type='text/css' href='style.css' title='Style'>\n";
         print HTMLFILE "</head>\n<body>\n";
@@ -1082,7 +1086,7 @@ sub CloseHtmlFiles($)
             my @lines = `grep '<i>Last revised' $htmlFile`;
             $fileDate = $1 if @lines and $lines[-1] =~ m{<i>Last revised (.*)</i>};
         }
-        open(HTMLFILE,">>$tmpFile") or $success = 0, next;
+        open(HTMLFILE, ">>$tmpFile") or $success = 0, next;
         # write the trailers
         print HTMLFILE "<hr>\n";
         print HTMLFILE "(This document generated automatically by Image::ExifTool::BuildTagLookup)\n";
@@ -1153,7 +1157,7 @@ sub WriteTagNames($$)
     my $percent = int(100 / $columns);
 
     # open the file and write the header
-    open(PODFILE,">$podFile") or return 0;
+    open(PODFILE, ">$podFile") or return 0;
     print PODFILE Doc2Pod($docs{PodHeader}), $docs{ExifTool}, $docs{ExifTool2};
     mkdir "$htmldir/TagNames";
     OpenHtmlFile($htmldir) or return 0;
@@ -1230,7 +1234,7 @@ sub WriteTagNames($$)
                 my $wid = 0;
                 my @keys;
                 foreach (sort NumbersFirst keys %$printConv) {
-                    next if /^(Notes|PrintHex)$/;
+                    next if /^(Notes|PrintHex|PrintString)$/;
                     $align = '' if $align and /[^\d]/;
                     my $w = length($_) + length($$printConv{$_});
                     $wid = $w if $wid < $w;
@@ -1257,7 +1261,9 @@ sub WriteTagNames($$)
                             $prt = "= $$printConv{$key}";
                             if ($$printConv{PrintHex}) {
                                 $index = sprintf('0x%x',$index);
-                            } elsif ($index !~ /^[+-]?(?=\d|\.\d)\d*(\.\d*)?$/) {
+                            } elsif ($$printConv{PrintString} or
+                                $index !~ /^[+-]?(?=\d|\.\d)\d*(\.\d*)?$/)
+                            {
                                 $index = "'" . EscapeHTML($index) . "'";
                             }
                         } else {
