@@ -5,11 +5,14 @@
 #
 # Revisions:    05/16/2006 - P. Harvey Created
 #               06/07/2007 - PH Added support for FLV (Flash Video) files
+#               10/23/2008 - PH Added support for XMP in FLV and SWF
 #
 # References:   1) http://www.the-labs.com/MacromediaFlash/SWF-Spec/SWFfileformat.html
 #               2) http://sswf.sourceforge.net/SWFalexref.html
 #               3) http://osflash.org/flv/
 #               4) http://www.irisa.fr/texmex/people/dufouil/ffmpegdoxy/flv_8h.html
+#               5) http://www.adobe.com/devnet/xmp/pdfs/XMPSpecificationPart3.pdf (Oct 2008)
+#               6) http://www.adobe.com/devnet/swf/pdf/swf_file_format_spec_v9.pdf
 #
 # Notes:        I'll add AMF3 support if someone sends me a FLV with AMF3 data
 #------------------------------------------------------------------------------
@@ -21,16 +24,19 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::FLAC;
 
-$VERSION = '1.03';
+$VERSION = '1.05';
 
 sub ProcessMeta($$$;$);
 
+# Meta packets that we process
+my %processMetaPacket = ( onMetaData => 1, onXMPData => 1 );
+
 # information extracted from SWF header
 %Image::ExifTool::Flash::Main = (
     GROUPS => { 2 => 'Video' },
     NOTES => q{
-        The information below is extracted from the header of SWF (Shockwave Flash)
-        files.
+        The information below is extracted from SWF (Shockwave Flash) files.  Tags
+        with string ID's represent information extracted from the file header.
     },
     FlashVersion => { },
     Compressed   => { PrintConv => { 0 => 'False', 1 => 'True' } },
@@ -40,7 +46,19 @@ sub ProcessMeta($$$;$);
     FrameCount   => { },
     Duration => {
         Notes => 'calculated from FrameRate and FrameCount',
-        PrintConv => 'sprintf("%.2f s",$val)',
+        PrintConv => 'ConvertDuration($val)',
+    },
+    69 => {
+        Name => 'FileAttributes',
+        PrintConv => { BITMASK => {
+            0 => 'UseNetwork',
+            3 => 'ActionScript3',
+            4 => 'HasMetadata',
+        } },
+    },
+    77 => {
+        Name => 'XMP',
+        SubDirectory => { TagTable => 'Image::ExifTool::XMP::Main' },
     },
 );
 
@@ -155,7 +173,7 @@ sub ProcessMeta($$$;$);
     'datasize'      => 'DataSize',
     'duration' => {
         Name => 'Duration',
-        PrintConv => 'sprintf("%.3f s",$val)',
+        PrintConv => 'ConvertDuration($val)',
     },
     'filesize'      => 'FileSizeBytes',
     'framerate'     => {
@@ -187,6 +205,11 @@ sub ProcessMeta($$$;$);
     },
     'videosize'     => 'VideoSize',
     'width'         => 'ImageWidth',
+    # tags in 'onXMPData' packets
+    'liveXML'       => { #5
+        Name => 'XMP',
+        SubDirectory => { TagTable => 'Image::ExifTool::XMP::Main' },
+    },
 );
 
 # tags in Flash META CuePoint structure
@@ -237,7 +260,6 @@ sub ProcessMeta($$$;$)
     my $dataPos = $$dirInfo{DataPos};
     my $dirLen = $$dirInfo{DirLen} || length($$dataPt);
     my $pos = $$dirInfo{Pos} || 0;
-    my $verbose = $exifTool->Options('Verbose');
     my ($type, $val, $rec);
 
     $exifTool->VerboseDir('Meta') unless $single;
@@ -315,8 +337,12 @@ Record: for ($rec=0; ; ++$rec) {
                 my $tagInfo = $$subTablePtr{$tag};
                 # switch to subdirectory table if necessary
                 if ($tagInfo and $$tagInfo{SubDirectory}) {
-                    $tag = $$tagInfo{Name}; # use our name for the tag
-                    $subTablePtr = GetTagTable($tagInfo->{SubDirectory}->{TagTable});
+                    my $subTable = $tagInfo->{SubDirectory}->{TagTable};
+                    # descend into Flash SubDirectory
+                    if ($subTable =~ /^Image::ExifTool::Flash::/) {
+                        $tag = $$tagInfo{Name}; # use our name for the tag
+                        $subTablePtr = GetTagTable($subTable);
+                    }
                 }
                 # get object value
                 my $valPos = $pos + 1;
@@ -335,7 +361,7 @@ Record: for ($rec=0; ; ++$rec) {
                 last if $t == 0x09; # (end of object)
                 if (not $$subTablePtr{$tag} and $tag =~ /^\w+$/) {
                     Image::ExifTool::AddTagToTable($subTablePtr, $tag, { Name => ucfirst($tag) });
-                    $verbose > 1 and $exifTool->VPrint(1, "  | (adding $tag)\n");
+                    $exifTool->VPrint(1, "  | (adding $tag)\n");
                 }
                 $exifTool->HandleTag($subTablePtr, $tag, $v,
                     DataPt  => $dataPt,
@@ -386,11 +412,11 @@ Record: for ($rec=0; ; ++$rec) {
         }
         last if $single;        # all done if extracting single value
         unless ($isStruct{$type}) {
-            # only process "onMetaData" Meta packets
+            # only process certain Meta packets
             if ($type == 0x02 and not $rec) {
-                my $verb = ($val eq 'onMetaData') ? 'processing' : 'ignoring';
+                my $verb = $processMetaPacket{$val} ? 'processing' : 'ignoring';
                 $exifTool->VPrint(0, "  | ($verb $val information)\n");
-                last unless $val eq 'onMetaData';
+                last unless $processMetaPacket{$val};
             } else {
                 # give verbose indication if we ignore a lone value
                 my $t = $amfType[$type] || sprintf('type 0x%x',$type);
@@ -479,6 +505,57 @@ sub FoundFlashTag($$$)
     $exifTool->HandleTag(\%Image::ExifTool::Flash::Main, $tag, $val);
 }
 
+#------------------------------------------------------------------------------
+# Read data from possibly compressed file
+# Inputs: 0) RAF reference, 1) data buffer, 2) bytes to read, 2) compressed flag
+# Returns: number of bytes read (may be greater than requested bytes if compressed)
+# - concatinates data to current buffer
+# - updates compressed flag with reference to inflate object for future calls
+#   (or sets to error message and returns zero on error)
+sub ReadCompressed($$$$)
+{
+    my ($raf, $len, $inflate) = ($_[0], $_[2], $_[3]);
+    my $buff;
+    unless ($raf->Read($buff, $len)) {
+        $_[3] = 'Error reading file';
+        return 0;
+    }
+    # uncompress if necessary
+    if ($inflate) {
+        unless (ref $inflate) {
+            unless (eval 'require Compress::Zlib') {
+                $_[3] = 'Install Compress::Zlib to extract compressed information';
+                return 0;
+            }
+            $inflate = Compress::Zlib::inflateInit();
+            unless ($inflate) {
+                $_[3] = 'Error initializing inflate for Flash data';
+                return 0;
+            }
+            $_[3] = $inflate;   # pass inflate object back to caller
+        }
+        my $tmp = $buff;
+        $buff = '';
+        # read 64 more bytes at a time and inflate until we get enough uncompressed data
+        for (;;) {
+            my ($dat, $stat) = $inflate->inflate($tmp);
+            if ($stat == Compress::Zlib::Z_STREAM_END() or
+                $stat == Compress::Zlib::Z_OK())
+            {
+                $buff .= $dat;  # add inflated data to buffer
+                last if length $buff >= $len or $stat == Compress::Zlib::Z_STREAM_END();
+                $raf->Read($tmp,64) or last;    # must read a bit more data
+            } else {
+                $buff = '';
+                last;
+            }
+        }
+        $_[3] = 'Error inflating compressed Flash data' unless length $buff;
+    }
+    $_[1] = defined $_[1] ? $_[1] . $buff : $buff;
+    return length $buff;
+}
+
 #------------------------------------------------------------------------------
 # Read information frame a Flash file
 # Inputs: 0) ExifTool object reference, 1) Directory information reference
@@ -486,59 +563,32 @@ sub FoundFlashTag($$$)
 sub ProcessSWF($$)
 {
     my ($exifTool, $dirInfo) = @_;
-    my $verbose = $exifTool->Options('Verbose');
     my $raf = $$dirInfo{RAF};
-    my $buff;
+    my ($buff, $inflate, $hasMeta);
 
     $raf->Read($buff, 8) == 8 or return 0;
     $buff =~ /^(F|C)WS([^\0])/ or return 0;
     my ($compressed, $vers) = ($1 eq 'C' ? 1 : 0, ord($2));
 
-    # read the first bit of the file
-    $raf->Read($buff, 64) or return 0;
-
+    SetByteOrder('II');
     $exifTool->SetFileType();
     GetTagTable('Image::ExifTool::Flash::Main');  # make sure table is initialized
 
     FoundFlashTag($exifTool, FlashVersion => $vers);
     FoundFlashTag($exifTool, Compressed => $compressed);
 
-    # uncompress if necessary
-    if ($compressed) {
-        unless (eval 'require Compress::Zlib') {
-            $exifTool->Warn('Install Compress::Zlib to extract compressed information');
-            return 1;
-        }
-        my $inflate = Compress::Zlib::inflateInit();
-        my $tmp = $buff;
-        $buff = '';
-        # read file 64 bytes at a time and inflate until we get enough uncompressed data
-        for (;;) {
-            unless ($inflate) {
-                $exifTool->Warn('Error inflating compressed Flash data');
-                return 1;
-            }
-            my ($dat, $stat) = $inflate->inflate($tmp);
-            if ($stat == Compress::Zlib::Z_STREAM_END() or
-                $stat == Compress::Zlib::Z_OK())
-            {
-                $buff .= $dat;  # add inflated data to buffer
-                last if length $buff >= 64 or $stat == Compress::Zlib::Z_STREAM_END();
-                $raf->Read($tmp,64) or last;    # read some more data
-            } else {
-                undef $inflate; # issue warning the next time around
-            }
-        }
+    # read the next 64 bytes of the file (and inflate if necessary)
+    $buff = '';
+    unless (ReadCompressed($raf, $buff, 64, $compressed)) {
+        $exifTool->Warn($compressed) if $compressed;
+        return 1;
     }
+
     # unpack elements of bit-packed Flash Rect structure
-    my ($nBits, $totBits, $nBytes);
-    for (;;) {
-        if (length($buff)) {
-            $nBits = unpack('C', $buff) >> 3;    # bits in x1,x2,y1,y2 elements
-            $totBits = 5 + $nBits * 4;           # total bits in Rect structure
-            $nBytes = int(($totBits + 7) / 8);   # byte length of Rect structure
-            last if length $buff >= $nBytes + 4; # make sure header is long enough
-        }
+    my $nBits = unpack('C', $buff) >> 3;    # bits in x1,x2,y1,y2 elements
+    my $totBits = 5 + $nBits * 4;           # total bits in Rect structure
+    my $nBytes = int(($totBits + 7) / 8);   # byte length of Rect structure
+    if (length $buff < $nBytes + 4) {
         $exifTool->Warn('Truncated Flash file');
         return 1;
     }
@@ -558,6 +608,57 @@ sub ProcessSWF($$)
     FoundFlashTag($exifTool, FrameCount => $vals[1]);
     FoundFlashTag($exifTool, Duration => $vals[1] * 256 / $vals[0]) if $vals[0];
 
+    # scan through the tags to find FileAttributes and XMP
+    $buff = substr($buff, $nBytes + 4);
+    for (;;) {
+        my $buffLen = length $buff;
+        last if $buffLen < 2;
+        my $code = Get16u(\$buff, 0);
+        my $pos = 2;
+        my $tag = $code >> 6;
+        my $size = $code & 0x3f;
+        $exifTool->VPrint(1, "SWF tag $tag ($size bytes):\n");
+        last unless $tag == 69 or $tag == 77 or $hasMeta;
+        # read enough to get a complete short record
+        if ($pos + $size > $buffLen) {
+            # (read 2 extra bytes if available to get next tag word)
+            unless (ReadCompressed($raf, $buff, $size + 2, $compressed)) {
+                $exifTool->Warn($compressed) if $compressed;
+                return 1;
+            }
+            $buffLen = length $buff;
+            last if $pos + $size > $buffLen;
+        }
+        # read extended record if necessary
+        if ($size == 0x3f) {
+            last if $pos + 4 > $buffLen;
+            $size = Get32u(\$buff, $pos);
+            $pos += 4;
+            last if $size > 1000000; # don't read anything huge
+            if ($pos + $size > $buffLen) {
+                unless (ReadCompressed($raf, $buff, $size + 2, $compressed)) {
+                    $exifTool->Warn($compressed) if $compressed;
+                    return 1;
+                }
+                $buffLen = length $buff;
+                last if $pos + $size > $buffLen;
+            }
+            $exifTool->VPrint(1, "  [extended size $size bytes]\n");
+        }
+        if ($tag == 69) {       # FileAttributes
+            last unless $size;
+            my $flags = Get8u(\$buff, $pos);
+            FoundFlashTag($exifTool, $tag => $flags);
+            last unless $flags & 0x10;  # only continue if we have metadata (XMP)
+            $hasMeta = 1;
+        } elsif ($tag == 77) {  # Metadata
+            my $val = substr($buff, $pos, $size);
+            FoundFlashTag($exifTool, $tag => $val);
+            last;
+        }
+        last if $pos + 2 > $buffLen;
+        $buff = substr($buff, $pos);    # remove everything before the next tag
+    }
     return 1;
 }
 
@@ -603,6 +704,8 @@ under the same terms as Perl itself.
 
 =item L<http://www.irisa.fr/texmex/people/dufouil/ffmpegdoxy/flv_8h.html>
 
+=item L<http://www.adobe.com/devnet/swf/pdf/swf_file_format_spec_v9.pdf>
+
 =back
 
 =head1 SEE ALSO
