@@ -19,7 +19,7 @@ use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 use Image::ExifTool::ASF;   # for GetGUID()
 
-$VERSION = '1.04';
+$VERSION = '1.06';
 
 sub ProcessFPX($$);
 sub ProcessFPXR($$$);
@@ -409,7 +409,7 @@ my @dirEntryType = qw(INVALID STORAGE STREAM LOCKBYTES PROPERTY ROOT);
     0x25000009 => {
         Name => 'FocalLength',
         Groups => { 2 => 'Camera' },
-        PrintConv => 'sprintf("%.1fmm",$val)',
+        PrintConv => 'sprintf("%.1f mm",$val)',
     },
     0x2500000A => {
         Name => 'MaxApertureValue',
@@ -896,7 +896,7 @@ sub ReadFPXValue($$$$$;$)
             push @vals, $val;
         }
         # join VT_ values with commas unless we want an array
-        @vals = ( join ', ', @vals ) if @vals > 1 and not wantarray;
+        @vals = ( join $exifTool->Options('ListSep'), @vals ) if @vals > 1 and not wantarray;
         last;   # didn't really want to loop
     }
     $_[2] = $valPos;    # return updated value position
@@ -1270,6 +1270,7 @@ sub ProcessFPX($$)
 
     if ($verbose) {
         $out = $exifTool->Options('TextOut');
+        $dumpParms{Out} = $out;
         $dumpParms{MaxLen} = 96 if $verbose == 3;
         print $out "  Sector size=$sectSize\n  FAT: Count=$fatCount\n";
         print $out "  DIR: Start=$dirStart\n";
@@ -1468,7 +1469,7 @@ JPEG images.
 
 =head1 AUTHOR
 
-Copyright 2003-2007, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2008, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
