@@ -12,7 +12,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.18';
+$VERSION = '1.21';
 
 my %coordConv = (
     ValueConv    => 'Image::ExifTool::GPS::ToDegrees($val)',
@@ -81,6 +81,8 @@ my %coordConv = (
     0x0006 => {
         Name => 'GPSAltitude',
         Writable => 'rational64u',
+        # extricate unsigned decimal number from string
+        ValueConvInv => '$val=~/((?=\d|\.\d)\d*(?:\.\d*)?)/ ? $1 : undef',
         PrintConv => '$val eq "inf" ? $val : "$val m"',
         PrintConvInv => '$val=~s/\s*m$//;$val',
     },
@@ -125,11 +127,12 @@ my %coordConv = (
         Writable => 'string',
         Count => 2,
         PrintConv => {
-            A => 'Measurement In Progress',
-            V => 'Measurement Interoperability',
+            A => 'Measurement Active', # Exif2.2 "Measurement in progress"
+            V => 'Measurement Void',   # Exif2.2 "Measurement Interoperability" (WTF?)
+            # (meaning for 'V' taken from status code in NMEA GLL and RMC sentences)
         },
     },
-    0x000A => {
+    0x000a => {
         Name => 'GPSMeasureMode',
         Writable => 'string',
         Count => 2,
@@ -138,12 +141,12 @@ my %coordConv = (
             3 => '3-Dimensional Measurement',
         },
     },
-    0x000B => {
+    0x000b => {
         Name => 'GPSDOP',
         Description => 'GPS Dilution Of Precision',
         Writable => 'rational64u',
     },
-    0x000C => {
+    0x000c => {
         Name => 'GPSSpeedRef',
         Writable => 'string',
         Count => 2,
@@ -153,11 +156,11 @@ my %coordConv = (
             N => 'knots',
         },
     },
-    0x000D => {
+    0x000d => {
         Name => 'GPSSpeed',
         Writable => 'rational64u',
     },
-    0x000E => {
+    0x000e => {
         Name => 'GPSTrackRef',
         Writable => 'string',
         Count => 2,
@@ -166,7 +169,7 @@ my %coordConv = (
             T => 'True North',
         },
     },
-    0x000F => {
+    0x000f => {
         Name => 'GPSTrack',
         Writable => 'rational64u',
     },
@@ -240,23 +243,23 @@ my %coordConv = (
             N => 'Nautical Miles',
         },
     },
-    0x001A => {
+    0x001a => {
         Name => 'GPSDestDistance',
         Writable => 'rational64u',
     },
-    0x001B => {
+    0x001b => {
         Name => 'GPSProcessingMethod',
         Writable => 'undef',
-        PrintConv => 'Image::ExifTool::Exif::ConvertExifText($self,$val)',
-        PrintConvInv => 'Image::ExifTool::Exif::EncodeExifText($self,$val)',
+        RawConv => 'Image::ExifTool::Exif::ConvertExifText($self,$val)',
+        RawConvInv => 'Image::ExifTool::Exif::EncodeExifText($self,$val)',
     },
-    0x001C => {
+    0x001c => {
         Name => 'GPSAreaInformation',
         Writable => 'undef',
-        PrintConv => 'Image::ExifTool::Exif::ConvertExifText($self,$val)',
-        PrintConvInv => 'Image::ExifTool::Exif::EncodeExifText($self,$val)',
+        RawConv => 'Image::ExifTool::Exif::ConvertExifText($self,$val)',
+        RawConvInv => 'Image::ExifTool::Exif::EncodeExifText($self,$val)',
     },
-    0x001D => {
+    0x001d => {
         Name => 'GPSDateStamp',
         Groups => { 2 => 'Time' },
         Writable => 'string',
@@ -268,7 +271,7 @@ my %coordConv = (
         # pull date out of any format date/time string
         PrintConvInv => '$val=~/(\d{4}).*?(\d{2}).*?(\d{2})/ ? "$1:$2:$3" : $val',
     },
-    0x001E => {
+    0x001e => {
         Name => 'GPSDifferential',
         Writable => 'int16u',
         PrintConv => {
@@ -306,6 +309,14 @@ my %coordConv = (
         ValueConv => '$val[1] =~ /^W/i ? -$val[0] : $val[0]',
         PrintConv => 'Image::ExifTool::GPS::ToDMS($self, $val, 1, "E")',
     },
+    GPSAltitude => {
+        Require => {
+            0 => 'GPS:GPSAltitude',
+            1 => 'GPS:GPSAltitudeRef',
+        },
+        ValueConv => '$val[1] ? "-$val[0]" : $val[0]',
+        PrintConv => '($val =~ s/^-// ? "$val m Below" : "$val m Above") . " Sea Level"'
+    },
 );
 
 # add our composite tags
